.. _diffusion-laplace_shifted_periodic:

diffusion/laplace_shifted_periodic.py
=====================================

**Description**


Laplace equation with shifted periodic BCs.

Display using::

  sfepy-view laplace_shifted_periodic.vtk -f u:wu:f0.5 1:vw


.. image:: /../doc/images/gallery/diffusion-laplace_shifted_periodic.png


:download:`source code </../sfepy/examples/diffusion/laplace_shifted_periodic.py>`

.. literalinclude:: /../sfepy/examples/diffusion/laplace_shifted_periodic.py

